#!/usr/bin/env python3

from argparse import ArgumentParser

if __name__ == '__main__':
    args_parser = ArgumentParser(description='test github-actions')
    args_parser.add_argument('--print', help='print this argument', default=None)
    args = args_parser.parse_args()
    if args.print is not None:
        print(args.print)



from setuptools import setup

setup(
    name='test-gh-actions',
    packages=['test-gh-actions'],
    version=open('VERSION', 'r').read(),
    description='test-gh-actions',
    license='WTFPL',
    python_requires='>=3.5',
    install_requires=[],
    data_files=[('', ['VERSION'])],
    scripts=[],
)
